""" An extension of django ninja framework, providing a configurable password reset strategy"""
__version__ = "1.2.4"

default_app_config = "django_rest_passwordreset.apps.DjangoRestPasswordResetConfig"
